# Polisplexity Dashboard Overview

This document provides an overview of the structure and components included in the Polisplexity Digital Twin Dashboard. The dashboard is designed to monitor, analyze, and control the intelligent waste collection process using advanced data science, route optimization, and real-time social interaction monitoring.

## 📊 Dashboard Sections

### 1. KPI Metrics
**Location:** `index.html` → KPI Row

Displays key performance indicators for the waste management system:
- **Collection Volume**
- **Route Completion**
- **Optimization Efficiency**
- **Citizen Engagement Rate**
- **Growth**
- **Operational Balance**

These are real-time metrics generated from pre-op and post-op analytics.

---

### 2. Charts and Time Series
**Location:** `partials/dashboard_charts.html`

Visual analytics showing:
- **Collection Efficiency by Zone**
- **Optimization Impact on Costs and Routes**
- Progress bars and comparison widgets for different urban areas

Connected to data from optimization engines (VROOM/ORS) and real route performance.

---

### 3. Geographic Activity & Zone Metrics
**Location:** `partials/dashboard_map.html`

A vector map with live markers indicating:
- Active or inactive waste collection zones
- Depot locations
- Operational anomalies

Includes a table of materials collected across neighborhoods.

---

### 4. Social Digital Twin Dashboard
**Location:** `partials/dashboard_engagement.html`

Breaks down social interaction data from bots and apps:
- **Message Volume by Channel** (WhatsApp, Telegram, AR App, etc.)
- **Response Completion Rate per Network**
- **Interaction Duration and Prompt Depth**

Draws from live logs, AI parsing, and feedback bots.

---

## 🔧 Technologies Used

- **Django** + Django Templates
- **ApexCharts** for visualization
- **jQuery Vector Map** for interactive mapping
- **Remix Icon** system for sidebar icons
- **Modular `partials/` system** for dashboard composition

## 📁 File Structure

- `index.html` – Main dashboard structure
- `partials/dashboard_kpis.html` – KPI row
- `partials/dashboard_charts.html` – Time series row
- `partials/dashboard_map.html` – Geographic zone row
- `partials/dashboard_engagement.html` – Social interaction row

## 🔗 Data Sources

- Optimization logs (`vroom`, `ors`)
- Depot/zone JSON uploads
- Bot interaction databases (WhatsApp, Telegram, Facebook)
- A-Frame AR interaction points

## 🧠 Twin Integration

- **Physical Digital Twin**: Collection points, vehicle tracking, maps
- **Social Digital Twin**: Bots, user feedback, NLP classification

`